@@ -153,7 +153,7 @@ class Augmentor(MapDataPipe):
         self.config = config
 
     def __getitem__(self, index) -> MapDataPipe[T_co]:
-        return self.augmentation(self.datapipe[index], self.config)
+        return self.augmentation(self.datapipe[index], self.config, index)
 
     def __len__(self) -> MapDataPipe[T_co]:
         return len(self.datapipe)
